==> igniteui-react-charts-16.6.8.tgz: package/ES2015/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class BollingerBandWidthIndicator extends StrategyBasedIndicator {
    get_p5() {
        return new BollingerBandWidthIndicatorStrategy();
    }
    get p5() {
        return this.get_p5();
    }
    get_qi() {
        return BollingerBandWidthIndicator.$;
    }
    get qi() {
        return this.get_qi();
    }
    get qr() {
        return typeGetValue(this.c(BollingerBandWidthIndicator.qu));
    }
    set qr(a) {
        this.h(BollingerBandWidthIndicator.qu, a);
    }
    qb() {
        return this.qr;
    }
    get qq() {
        return this.c(BollingerBandWidthIndicator.qt);
    }
    set qq(a) {
        this.h(BollingerBandWidthIndicator.qt, a);
    }
    p9() {
        return this.qq;
    }
}
BollingerBandWidthIndicator.$t = markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
BollingerBandWidthIndicator.qu = StrategyBasedIndicator.qn(20, BollingerBandWidthIndicator.$);
BollingerBandWidthIndicator.qt = StrategyBasedIndicator.qm(2, BollingerBandWidthIndicator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/BollingerBandWidthIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { BollingerBandWidthIndicatorStrategy } from "./BollingerBandWidthIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class BollingerBandWidthIndicator extends StrategyBasedIndicator {
    get_qc() {
        return new BollingerBandWidthIndicatorStrategy();
    }
    get qc() {
        return this.get_qc();
    }
    get_qp() {
        return BollingerBandWidthIndicator.$;
    }
    get qp() {
        return this.get_qp();
    }
    get qy() {
        return typeGetValue(this.c(BollingerBandWidthIndicator.q1));
    }
    set qy(a) {
        this.h(BollingerBandWidthIndicator.q1, a);
    }
    qi() {
        return this.qy;
    }
    get qx() {
        return this.c(BollingerBandWidthIndicator.q0);
    }
    set qx(a) {
        this.h(BollingerBandWidthIndicator.q0, a);
    }
    qg() {
        return this.qx;
    }
}
BollingerBandWidthIndicator.$t = markType(BollingerBandWidthIndicator, 'BollingerBandWidthIndicator', StrategyBasedIndicator.$);
BollingerBandWidthIndicator.q1 = StrategyBasedIndicator.qu(20, BollingerBandWidthIndicator.$);
BollingerBandWidthIndicator.q0 = StrategyBasedIndicator.qt(2, BollingerBandWidthIndicator.$);
